@@ -1,3 +1,4 @@
+from urllib.parse import urljoin
 from rest_framework import authentication
 from django.contrib.auth.models import User
 from django.conf import settings
@@ -34,9 +35,10 @@ class IdentitySSOAuthentication(authentication.BaseAuthentication):
         if not shared_cookie:
             # auth not attempted
             return None
+
+        validate_url = urljoin(settings.IDENTITY_HOST, "internal/sessions/validate/")
         user_info_reply = requests.post(
-            f"{settings.IDENTITY_HOST}/auth/validate_sso_session/",
-            json={"sso_session_cookie": shared_cookie},
+            validate_url, json={"sso_session_cookie": shared_cookie},
         )
 
         try:
@@ -66,10 +68,9 @@ class IdentityAPIKeyAuthentication(authentication.BaseAuthentication):
         if not api_key:
             # auth not attempted
             return None
-        user_info_reply = requests.post(
-            f"{settings.IDENTITY_HOST}/internal/api_keys/validate/",
-            json={"api_key": api_key},
-        )
+
+        validate_url = urljoin(settings.IDENTITY_HOST, "internal/api_keys/validate/")
+        user_info_reply = requests.post(validate_url, json={"api_key": api_key},)
 
         try:
             user_info_reply.raise_for_status()
